@@ -1,19 +1,15 @@
-
-
-#' Get names of columns in site table
-#'
-#' @name validSpatialData
-#'
-#' @description Are the contents of @sp valid: n x 2 matrix? If not, then contents of @sp in the SoilProfileCollection are an empty SpatialPoints object.
-#' @param object a SoilProfileCollection
-#' @aliases validSpatialData,SoilProfileCollection-method
-#' @docType methods
-#' @rdname validSpatialData
-#'
-if (!isGeneric("validSpatialData"))
+# if (!isGeneric("validSpatialData"))
   setGeneric("validSpatialData", function(object, ...)
     standardGeneric("validSpatialData"))
 
+#' Get names of columns in site table
+#'
+#' @description Are the contents of @sp valid: n x 2 matrix? If not, then contents of @sp in the SoilProfileCollection are an empty SpatialPoints object.
+#' @param object a SoilProfileCollection
+#' @aliases validSpatialData
+#' @docType methods
+#' @rdname validSpatialData
+#'
 setMethod("validSpatialData", signature(object = "SoilProfileCollection"),
           function(object) {
             # n x 2 ---> valid / initialized coordinates
@@ -34,11 +30,9 @@ setMethod("validSpatialData", signature(object = "SoilProfileCollection"),
 
 #' Get names of columns in site and horizons table
 #'
-#' @name names
-#'
 #' @description Get names of columns in site and horizons table of a SoilProfileCollection.
 #' @param x a SoilProfileCollection
-#' @aliases names,SoilProfileCollection-method
+#' @aliases names
 #' @docType methods
 #' @rdname names
 #'
@@ -50,19 +44,17 @@ setMethod("names", signature("SoilProfileCollection"),
 
 # overload min() to give us the min depth within a collection
 #' Get the minimum bottom depth in a SoilProfileCollection
-#'
-#' @name min
-#'
 #' @description Get the shallowest depth of description out of all profiles in a SoilProfileCollection. Data missing one or more of: bottom depth, profile ID, or any optional attribute are omitted using \code{complete.cases}.
 #' @param x a SoilProfileCollection
 #' @param v optional: a vector of horizon attribute names to refine calculation
-#' @aliases min,SoilProfileCollection-method
+#' @param na.rm remove `NA`? default: `TRUE`
+#' @aliases min
 #' @docType methods
 #' @rdname min
 setMethod(
-  f = 'min',
+  f = "min",
   signature(x = "SoilProfileCollection"),
-  definition = function(x, v = NULL) {
+  definition = function(x, v = NULL, na.rm = TRUE) {
 
     htb <- horizonDepths(x)
     target.names <- c(idname(x), hzidname(x), htb)
@@ -84,26 +76,24 @@ setMethod(
     
     # return the shallowest (of the deepest depths in each profile)
     .LAST <- NULL
-    return(min(x[,, .LAST][[htb[2]]], na.rm = TRUE))
+    .HZID <- NULL
+    return(min(horizons(x)[x[,, .LAST, .HZID],][[htb[2]]], na.rm = na.rm))
   }
 )
 
 # overload max() to give us the max depth within a collection
 #' Get the maximum bottom depth in a SoilProfileCollection
-#'
-#' @name max
-#'
 #' @description Get the deepest depth of description out of all profiles in a SoilProfileCollection. Data missing one or more of: bottom depth, profile ID, or any optional attribute are omitted using \code{complete.cases}.
-#'
 #' @param x a SoilProfileCollection
 #' @param v optional: horizon-level column name to refine calculation
-#' @aliases max,SoilProfileCollection-method
+#' @param na.rm remove `NA`? default: `TRUE`
+#' @aliases max
 #' @docType methods
 #' @rdname max
 setMethod(
-  f = 'max',
+  f = "max",
   signature(x = "SoilProfileCollection"),
-  definition = function(x, v = NULL) {
+  definition = function(x, v = NULL, na.rm = TRUE) {
     htb <- horizonDepths(x)
     target.names <- c(idname(x), hzidname(x), htb)
     
@@ -122,24 +112,23 @@ setMethod(
     idx <- which(complete.cases(.data.frame.j(h, target.names, aqp_df_class(x))))
     x@horizons <- h[idx,]
     
+    
     # return the deepest (of the deepest depths in each profile)
     .LAST <- NULL
-    return(max(x[,, .LAST][[htb[2]]], na.rm = TRUE))
+    .HZID <- NULL
+    return(max(horizons(x)[x[,, .LAST, .HZID],][[htb[2]]], na.rm = na.rm))
   }
 )
 
 # overload length() to give us the number of profiles in the collection
 #' Get the number of profiles in a SoilProfileCollection
-#'
-#' @name length
-#'
 #' @description Get the number of profiles in a SoilProfileCollection
 #' @param x a SoilProfileCollection
-#' @aliases length,SoilProfileCollection-method
+#' @aliases length
 #' @docType methods
 #' @rdname length
 setMethod(
-  f = 'length',
+  f = "length",
   signature(x = "SoilProfileCollection"),
   definition = function(x) {
     # faster replacement for profile_id()
@@ -150,79 +139,112 @@ setMethod(
 )
 
 # overload nrow() to give us the number of horizons in the collection
+
+# do not need to define a generic at all if we use the base prototype
+# if (!isGeneric('nrow'))
+#   setGeneric('nrow', function(x)
+#     standardGeneric('nrow'))
+  
 #' Get the number of horizons in a SoilProfileCollection
-#'
-#' @name nrow
-#'
+#' @aliases nrow
 #' @description Get the number of horizons in a SoilProfileCollection
-#' @param object a SoilProfileCollection
-#' @aliases nrow,SoilProfileCollection-method
+#' @param x a SoilProfileCollection
 #' @docType methods
 #' @rdname nrow
-if (!isGeneric('nrow'))
-  setGeneric('nrow', function(x)
-    standardGeneric('nrow'))
-
 setMethod(
-  f = 'nrow',
+  f = "nrow",
   signature(x = "SoilProfileCollection"),
   definition = function(x) {
     nrow(x@horizons)
   }
 )
-#' Get the indexes of unique profiles in a SoilProfileCollection
-#'
-#' @name unique
-#'
-#' @description Calculate MD5 hash of each profile in a SoilProfileCollection for the specified variables.
-#'
-#' @param x a SoilProfileCollection
+  
+
+#' @title Uniqueness within a `SoilProfileCollection` via MD5 Hash
+#' @description Unique profiles within a `SoilProfileCollection` using and MD5 hash of select horizon and / or site level attributes.
+#' 
+#' @param x a `SoilProfileCollection`
 #' @param vars Variables to consider in uniqueness.
-#' @aliases unique,SoilProfileCollection-method
+#' @param SPC logical return a `SoilProfileCollection` when `TRUE`, otherwise vector of profile indices
+#' 
+#' @return `SoilProfileCollection` when `SPC = TRUE`, otherwise a vector of integers
+#' 
+#' @aliases unique
 #' @docType methods
 #' @rdname unique
+#' 
 #' @examples
 #'
-#' data(sp5)
+#'   # an example soil profile
+#'   x <- data.frame(
+#'     id = 'A',
+#'     name = c('A', 'E', 'Bhs', 'Bt1', 'Bt2', 'BC', 'C'),
+#'     top = c(0, 10, 20, 30, 40, 50, 100),
+#'     bottom = c(10, 20, 30, 40, 50, 100, 125),
+#'     z = c(8, 5, 3, 7, 10, 2, 12)
+#'   )
+#'   
+#'   # init SPC
+#'   depths(x) <- id ~ top + bottom
+#'   
+#'   # horizon depth variability for simulation
+#'   horizons(x)$.sd <- 2
+#'   
+#'   # duplicate several times
+#'   x.dupes <- duplicate(x, times = 5)
+#'   
+#'   # simulate some new profiles based on example
+#'   x.sim <- perturb(x, n = 5, thickness.attr = '.sd')
+#'   
+#'   # graphical check
+#'   plotSPC(x.dupes, name.style = 'center-center')
+#'   plotSPC(x.sim, name.style = 'center-center')
+#'   
+#'   # inspect unique results
+#'   plotSPC(unique(x.dupes, vars = c('top', 'bottom')), name.style = 'center-center')
+#'   
+#'   # uniqueness is a function of variable selection
+#'   plotSPC(unique(x.sim, vars = c('top', 'bottom')), name.style = 'center-center')
+#'   plotSPC(unique(x.sim, vars = c('name')), name.style = 'center-center')
+#'   
 #'
-#' # find indices where all specified vars are unique
-#' #  these match the indices of all profiles in sp5
-#' #  therefore, all profiles in sp5 are unique
-#'
-#' all(unique(sp5, vars=c("id","sand","silt","clay") == 1:length(sp5)))
 #'
 setMethod(f = 'unique',
           signature(x = "SoilProfileCollection"),
-          definition = function(x, vars) {
-  # compute hash by profile, for selected variables
-  md5 <- profileApply(x, function(i) {
-    # unlist in order to drop row names
-    #
-    if(!requireNamespace("digest", quietly = TRUE))
-       stop("package `digest` is required", call.=FALSE)
-
-    digest::digest(unlist(as(i, 'data.frame')[, vars]))
-  })
-
-  # get unique hashes
-  u.md5 <- unique(md5)
-
-  # list profile idx by hash:
-  profiles.by.hash <-
-    sapply(u.md5, function(i)
-      which(md5 == i), simplify = FALSE)
-
-  # get an index of the first copy of each profile
-  u.profiles <- sapply(profiles.by.hash, function(i)
-    i[1])
-
-  # return an index of unique profiles
-  # down-grade to un-named vector of indices
-  return(as.vector(u.profiles))
-})
-
+          definition = function(x, vars, SPC = TRUE) {
+  
+            if(!requireNamespace("digest", quietly = TRUE))
+              stop("package `digest` is required", call.=FALSE)
+            
+            # compute hash by profile, for selected variables
+            md5 <- profileApply(x, function(i) {
+              # unlist in order to drop row names
+              digest::digest(unlist(as(i, 'data.frame')[, vars]))
+            })
+            
+            # get unique hashes
+            u.md5 <- unique(md5)
+            
+            # list profile idx by hash:
+            profiles.by.hash <- sapply(u.md5, function(i) which(md5 == i), simplify = FALSE)
+            
+            # get an index of the first copy of each profile
+            u.profiles <- sapply(profiles.by.hash, function(i) i[1])
+            
+            # down-grade to un-named vector of indices
+            u.profiles <- as.vector(u.profiles)
+            
+            if(SPC) {
+              # return the unique set of profiles as an SPC
+              return(x[u.profiles, ])
+            } else {
+              # return an index of unique profiles
+              return(u.profiles)
+            }
+          }
+)
+  
 #' @title Subset a SoilProfileCollection with logical expressions
-#'
 #' @description \code{subset()} is a function used for subsetting SoilProfileCollections. It allows the user to specify an arbitrary number of logical vectors (equal in length to site or horizon), separated by commas. The function includes some support for non-standard evaluation found in the \code{tidyverse}. This greatly simplifies access to site and horizon-level variable compared to \code{subset.default}, as \code{`$`} or \code{`[[`} methods are not needed.
 #'
 #' @param x A SoilProfileCollection
@@ -322,7 +344,7 @@ setMethod("subset", signature(x = "SoilProfileCollection"),
               return(object[na.omit(idx),])
           })
 
-if (!isGeneric("filter"))
+# if (!isGeneric("filter"))
   setGeneric("filter", function(.data, ..., .preserve = FALSE)
     standardGeneric("filter"))
 
@@ -340,8 +362,61 @@ setMethod("filter", signature(.data = "SoilProfileCollection"),
             aqp::subset(x = .data, ...)
           })
 
+setGeneric("subsetHz", function(x, ...)
+  standardGeneric("subsetHz"))
+
+#' Subset the horizons in a SoilProfileCollection using logical criteria
+#'
+#' @param x a SoilProfileCollection
+#' @param ... Comma-separated set of R expressions that evaluate as `TRUE` or `FALSE` in context of horizon data frame. Length for individual expressions matches number of horizons, in \code{x}.
+#'
+#' @return a SoilProfileCollection with a subset of horizons, possibly with some sites removed
+#' @export
+#' @aliases subsetHz
+#' @examples
+#' 
+#' data(sp3)
+#' 
+#' depths(sp3) <- id ~ top + bottom
+#' 
+#' # show just horizons with 10YR hues
+#' plot(subsetHz(sp3, hue == '10YR'))
+#' 
+setMethod("subsetHz", signature(x = "SoilProfileCollection"), function(x, ...) {
+  # capture expression(s) at function
+  .dots <- substitute(list(...))
+  .dots <- .dots[2:length(.dots)]
+  
+  # create composite object to facilitate eval
+  .data <- horizons(x)
+  
+  # loop through list of expressions and evaluate
+  res <- vector('list', length(.dots))
+  for (i in 1:length(.dots)) {
+    res[[i]] <- eval(.dots[[i]], .data, parent.frame(n = 2))
+  }
+  
+  subcrit <- Reduce('&', res)
+  
+  if (!is.logical(subcrit)) {
+    badxpr <- paste0("'",paste0(.dots[sapply(.dots, function(x) !is.logical(x))],
+                                collapse=",'"),"'")
+    message(sprintf("%s is not logical; returning `x` unchanged", badxpr))
+    return(x)
+  }
+  
+  newhz <- .data[which(subcrit),]
+  
+  # subset SPC first to remove sites and other slots
+  x <- x[which(profile_id(x) %in% newhz[[idname(x)]]),]
+  
+  # then replace horizons with horizon subset 
+  #   (avoid profile IDs in site are missing from replacement horizons!)
+  replaceHorizons(x) <- newhz
+  x
+})
+
 # functions tailored for use with magrittr %>% operator / tidyr
-# formerly thisisnotapipe.R
 
 #' @title Subset SPC with pattern-matching for text-based attributes
 #' @name grepSPC
@@ -357,7 +432,7 @@ setMethod("filter", signature(.data = "SoilProfileCollection"),
 #' @rdname grepSPC
 #' @export grepSPC
 
-if (!isGeneric("grepSPC"))
+# if (!isGeneric("grepSPC"))
   setGeneric("grepSPC", function(object, attr, pattern, ...)
     standardGeneric("grepSPC"))
 
@@ -396,7 +471,7 @@ setMethod("grepSPC", signature(object = "SoilProfileCollection"),
 #' @rdname subApply
 #' @export subApply
 
-if (!isGeneric("subApply"))
+# if (!isGeneric("subApply"))
   setGeneric("subApply", function(object, .fun, ...)
     standardGeneric("subApply"))
 
@@ -416,7 +491,7 @@ setMethod("subApply", signature(object = "SoilProfileCollection"),
 ## s: site-level subsetting criteria (properly quoted)
 ## h: horizon-level subsetting criteria (properly quoted)
 ## result: SoilProfileCollection with all profiles that match _either_ criteria- i.e. greedy matching
-if (!isGeneric("subsetProfiles"))
+# if (!isGeneric("subsetProfiles"))
   setGeneric("subsetProfiles", function(object, s, h, ...)
     standardGeneric("subsetProfiles"))
 
@@ -429,7 +504,7 @@ if (!isGeneric("subsetProfiles"))
 #' via site or horizon-level attributes. The \code{h} argument supplies a fully-quoted
 #' search criteria for matching via horizon-level attributes. All horizons
 #' associated with a single horizon-level match (i.e. out of several, only a
-#' single horizon matches the search critera) are returned. See examples for
+#' single horizon matches the search criteria) are returned. See examples for
 #' usage.
 #' @name subsetProfiles
 #' @aliases subsetProfiles,SoilProfileCollection-method
