@@ -12,7 +12,7 @@ test_that("mixMunsell works as expected", {
   # singleton
   x <- mixMunsell(c('10YR 5/3'))
   expect_true(inherits(x, 'data.frame'))
-  expect_true(ncol(x) == 2)
+  expect_true(ncol(x) == 5)
   expect_true(nrow(x) == 1)
   expect_true(x$munsell == '10YR 5/3')
 
@@ -26,6 +26,7 @@ test_that("mixMunsell works as expected", {
   
   x <- mixMunsell(c('10YR 5/3', '10YR 3/2'), w = 1)
   expect_true(x$munsell == '10YR 4/2')
+  expect_equal(x$distance, 0.0046028, tolerance = 1e-4)
 
   # weights when length(x) != length(unique(x))
   expect_silent(mixMunsell(c('10YR 5/3', '10YR 3/2', '10YR 5/3')))
@@ -66,22 +67,28 @@ test_that("mxing methods", {
   
   ## all reference spectra available
   
-  # spectra
-  mx <- mixMunsell(c('10YR 6/2', '10YR 2/2'), mixingMethod = 'spectra')
+  # each method gives a slightly different result
+  
+  # exact
+  mx <- mixMunsell(c('10YR 6/2', '10YR 2/2'), mixingMethod = 'exact')
+  expect_true(mx$munsell[1] == '10YR 4/2')
+  
+  # reference
+  mx <- mixMunsell(c('10YR 6/2', '10YR 2/2'), mixingMethod = 'reference')
   expect_true(mx$munsell[1] == '10Y 4/3')
   
   # wt. mean CIELAB, results are slightly different
   mx <- mixMunsell(c('10YR 6/2', '10YR 2/2'), mixingMethod = 'estimate')
   expect_true(mx$munsell[1] == '10YR 4/2')
   
-  # adaptive, should get spectral mixture
+  # adaptive, should get exact mixture
   mx <- mixMunsell(c('10YR 6/2', '10YR 2/2'), mixingMethod = 'adaptive')
-  expect_true(mx$munsell[1] == '10Y 4/3')
+  expect_true(mx$munsell[1] == '10YR 4/2')
 
   ## some reference spectra missing
   
   # message and NA
-  expect_message(mx <- mixMunsell(c('10YR 6/2', '10YR 1/1'), mixingMethod = 'spectra'))
+  expect_message(mx <- mixMunsell(c('10YR 6/2', '10YR 1/1'), mixingMethod = 'reference'))
   expect_true(is.na(mx$munsell[1]))
   
   # fall-back to wt.mean CIELAB
@@ -90,3 +97,19 @@ test_that("mxing methods", {
   
 })
 
+test_that("additional arguments via ...", {
+  
+  # NO conversion to closest Munsell chip via rgb2munsell()
+  m <- mixMunsell(c('10YR 6/2', '10YR 2/2'), mixingMethod = 'exact', convert = FALSE)
+  
+  # verified results
+  expect_true(nrow(m) == 1)
+  
+  # additional columns
+  expect_true(
+    all(c('r', 'g', 'b') %in% names(m))
+  )
+  
+})
+
+
